AirAction class

A wrapper for Air actions to carry data and callbacks

Constructors

AirAction(dynamic data, {VoidCallback? onSuccess, void onError(String)?})

Properties

data → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
onError → void Function(String)?
final
onSuccess VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited