OnEnterResult class sealed
The result of an onEnter callback.
This sealed class represents the possible outcomes of navigation interception. This class can't be extended. One must use one of its subtypes, Allow or Block, to indicate the result.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStop → bool
-
Whether this block represents a hard stop without a follow-up callback.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- then → OnEnterThenCallback?
-
Executed after the decision is committed.
Errors are reported and do not revert navigation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited