QueryParameterEncoder<T> typedef

QueryParameterEncoder<T> = String Function(T value)

Signature of custom query parameter encoding.

The function takes a parameter value of type T and returns a string representation suitable for use in a URI. The returned string is escaped to be URL-safe.

For example, a parameter value of 'field with space' will generate a query parameter value of 'field+with+space'.

Implementation

typedef QueryParameterEncoder<T> = String Function(T value);