pushReplacementRelative method
Replaces the top-most page of the page stack with the route.
Implementation
void pushReplacementRelative(BuildContext context) =>
throw _GoRouteDataBase.shouldBeGeneratedError;
Replaces the top-most page of the page stack with the route.
void pushReplacementRelative(BuildContext context) =>
throw _GoRouteDataBase.shouldBeGeneratedError;