AdapterLifecycleState enum

Lifecycle state of an adapter

Inheritance
Available extensions

Values

unloaded → const AdapterLifecycleState
binding → const AdapterLifecycleState
bound → const AdapterLifecycleState
initializing → const AdapterLifecycleState
initialized → const AdapterLifecycleState
disposing → const AdapterLifecycleState
disposed → const AdapterLifecycleState

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AdapterLifecycleState>
A constant List of the values in this enum, in order of their declaration.