core/core library

Classes

AdapterManager
Manages all registered adapters in the Air Framework.
AirAdapter
Base interface for all Adapters in the Air Framework.
AppModule
Base interface for all modules in the Air Framework.
ModuleManager
Manages all registered modules in the Air Framework.

Enums

AdapterLifecycleState
Lifecycle state of an adapter
ModuleLifecycleState
Lifecycle state of a module