AirController<T> class
A reactive state container for 'Air' A reactive state container for the Air Framework.
AirController holds a value of type T and notifies listeners when the value changes.
It integrates with the Air system to allow global access and automatic dependency tracking
with AirBuilder and AirView.
- Inheritance
-
- Object
- ChangeNotifier
- AirController
Constructors
- AirController(T _value, {required String key})
-
Creates a new AirController with an initial
_valueand a requiredkey.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- key → String
-
The unique key identifying this state in the Air system.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T
-
The current value of the state.
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
forceNotify(
{String? sourceModuleId}) → void - Forces notification to listeners after in-place mutation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setValue(
T newValue, {String? sourceModuleId, bool silent = false, bool force = false}) → void - Updates value with source tracking for AirGraph.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
T updater(T current)) → void -
Updates the value using a transformation function
updater.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited