ComputedState<T> class
A computed state that derives from other states
Constructors
Properties
-
compute
→ T Function(Map<
String, dynamic> states) -
Function to compute the derived value
final
-
dependencies
→ List<
String> -
List of state keys this computation depends on
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
Optional debug name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
evaluate(
) → T - Evaluate this computed state with current Air state values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited